help.zelig <- function(object) {
  # Elements of this function use functions from the Hmisc library for
  # R by Frank E Harrell Jr, distributed under the GNU GPL v.2.
  under.unix   <- !(version$os=='Microsoft Windows' ||
                    version$os=='Win32' || version$os=='mingw32')
  sys <- function (command, text = NULL) {
    cmd <- if (length(text)) 
        paste(command, text)
    else command
    if (under.unix) 
        system(cmd)
    else shell(cmd, wait = TRUE)
  }
  browser <- .Options$help.browser
  if(!length(browser)) browser <- .Options$browser
  if(!length(browser)) browser <- getOption("browser")
  url <- NULL
  if (is.character(object)) {
    if (object == "command" || object == "commands")
      url<-c("http://gking.harvard.edu/zelig/docs/Main_Commands.html")
    else if (object == "model" || object == "models")
      url<-c("http://gking.harvard.edu/zelig/docs/Specific_Models.html")
    else if (object == "zelig")
      url<-c("http://gking.harvard.edu/zelig/docs/_TT_zelig_TT__Estimati.html")
    else if (object == "setx")
      url<-c("http://gking.harvard.edu/zelig/docs/_TT_setx_TT__Setting_E.html")
    else if (object == "sim")
      url<-c("http://gking.harvard.edu/zelig/docs/_TT_sim_TT__Simulating.html")
    else if (object == "matchit" || object == "MatchIt")
      url<-c("http://gking.harvard.edu/zelig/docs/_TT_matchit_TT__Create.html")
    else if (object == "summary")
      url<-c("http://gking.harvard.edu/zelig/docs/_TT_summary_TT__Summar.html")
    else if (object == "print")
      url<-c("http://gking.harvard.edu/zelig/docs/_TT_print_TT__Printing.html")
    else if (object == "plot")
      url<-c("http://gking.harvard.edu/zelig/docs/_TT_plot_TT__Graphing.html")
    else if (object == "plot.ci")
      url<-c("http://gking.harvard.edu/zelig/docs/_TT_plot_ci_TT__Plotti.html")
    else if (object == "roc" || object == "rocplot" || object == "ROC")
      url<-c("http://gking.harvard.edu/zelig/docs/_TT_rocplot_TT__Receiv.html")
    else if (object == "ternarypoints" || object == "ternary")
      url<-c("http://gking.harvard.edu/zelig/docs/_TT_ternarypoints_TT.html")
    else if (object == "repl")
      url<-c("http://gking.harvard.edu/zelig/docs/_TT_repl_TT__Replicati.html")
    else if (object == "blogit")
      url<-c("http://gking.harvard.edu/zelig/docs/_TT_blogit_TT__Bivaria.html")
    else if (object == "bprobit")
      url<-c("http://gking.harvard.edu/zelig/docs/_TT_bprobit_TT__Bivari.html")
    else if (object == "exp")
      url<-c("http://gking.harvard.edu/zelig/docs/_TT_exp_TT__Exponentia.html")
    else if (object == "gamma")
      url<-c("http://gking.harvard.edu/zelig/docs/_TT_gamma_TT__Gamma_Re.html")
    else if (object == "ls")
      url<-c("http://gking.harvard.edu/zelig/docs/_TT_ls_TT__Least_Squar.html")
    else if (object == "logit")
      url<-c("http://gking.harvard.edu/zelig/docs/_TT_logit_TT__Logistic.html")
    else if (object == "lognorm")
      url<-c("http://gking.harvard.edu/zelig/docs/_TT_lognorm_TT__Log_No.html")
    else if (object == "mlogit")
      url<-c("http://gking.harvard.edu/zelig/docs/_TT_mlogit_TT__Multino.html")
    else if (object == "mloglm")
      url<-c("http://gking.harvard.edu/zelig/docs/_TT_mloglm_TT__Multino.html")
    else if (object == "negbin")
      url<-c("http://gking.harvard.edu/zelig/docs/_TT_negbin_TT__Negativ.html")
    else if (object == "normal")
      url<-c("http://gking.harvard.edu/zelig/docs/_TT_normal_TT__Normal.html")
    else if (object == "ologit")
      url<-c("http://gking.harvard.edu/zelig/docs/_TT_ologit_TT__Ordinal.html")
    else if (object == "oprobit")
      url<-c("http://gking.harvard.edu/zelig/docs/_TT_oprobit_TT__Ordina.html")
    else if (object == "poisson")
      url<-c("http://gking.harvard.edu/zelig/docs/_TT_poisson_TT__Poisso.html")
    else if (object == "probit")
      url<-c("http://gking.harvard.edu/zelig/docs/_TT_probit_TT__Probit.html")
    else if (object == "relogit")
      url<-c("http://gking.harvard.edu/zelig/docs/_TT_relogit_TT__Rare_E.html")
    else if (object == "weibull")
      url<-c("http://gking.harvard.edu/zelig/docs/_TT_weibull_TT__Weibul.html")
  }
  else 
    stop("Please enclose the requested topic \n in quotes and try again.")
  if (is.null(url)) {
    cat("Warning: Requested topic not found in Zelig help.  \n If you are sure the topic exists, please check \n the full documentation at http://gking.harvard.edu/zelig.  \n Now searching R-help.\n\n")
    topic <- as.name(object)
    do.call("help", list(topic, htmlhelp = TRUE))
  }
  else {
    if (under.unix) {
      sys(paste(browser, url, '&'))
      invisible()
    }
    if (!under.unix) {
      browseURL(url, browser = browser)
      invisible("")
    }
  }
}









