relogit<-function(formula, data=sys.parent(), tau, bias.correct=TRUE,
                 ...){
  mf <- match.call()
  mf$tau <- mf$bias.correct <- mf$... <- NULL
  tau <- unique(tau)
    relog <- function(formula=formula, data=data, tau=tau,
                 bias.correct=bias.correct, ...) {
    mf[[1]] <- as.name("glm")
    mf$family <- as.name("binomial")
    res <- eval(as.call(mf))
    ## bias correction
    if (bias.correct){
      pihat <- fitted(res)
      X <- model.matrix(res)
      W <- diag(pihat * (1 - pihat))
      Z <- solve(t(X) %*% W %*% X)
      xi <- diag(X %*% Z %*% t(X)) * (pihat-0.5)
      res$coefficients <- res$coefficients-
        c(Z %*% t(X) %*% W %*% as.matrix(xi))
    }
    ## prior correction
    if (!is.null(tau)){
      if (tau <= 0 || tau >= 1)
        stop("\ntau needs to be between 0 and 1.\n")
      ybar <- mean(res$y)  
      res$coefficients["(Intercept)"] <-
        res$coefficients["(Intercept)"]-
          log(((1-tau)/tau) * (ybar/(1-ybar)))
    }
    res$linear.predictors <- res$coef %*% t(X) 
    res$fitted.values <- 1/(1+exp(-res$linear.predictors))
    res
  }
  if (length(tau) > 2)
    stop("tau must be a vector of length less than or equal to 2")
  else if (is.null(tau) || length(tau) == 1) 
    res <- relog(mf, data, tau, bias.correct)
  else if(length(tau) == 2){ # without full population information
    lower <- relog(mf, data, min(tau), bias.correct)
    upper <- relog(mf, data, max(tau), bias.correct)
    lower$zelig <- upper$zelig <- "relogit"
    res <- list(lower.estimate=lower, upper.estimate=upper,
                terms = lower$terms)
  }
  res$zelig <- "relogit"
  class(res) <- "relogit"
  res
}

