sim.relogit <- function(object, x, x1 = NULL, num=c(1000, 100), prev =
  NULL, bootstrap = FALSE, bootfn = NULL, ...){
  res <- list(x = x, x1 = x1)
  res$call <- match.call()
  res$zelig.call <- object$call
  if (length(num) == 2) {
    if(bootstrap) num <- num[2]
    else num <- num[1]
  }
  tau <- eval(object$call$tau, sys.parent())
  if (length(tau) == 2){ # without full population information
    if (is.null(prev)) {
      pping <- function(object, x, x1, num, bootstrap, bootfn,...) {
        if(!bootstrap) {
          par0 <- param.default(object$lower.estimate, num=num, bootstrap=bootstrap)
          par1 <- param.default(object$upper.estimate, num=num, bootstrap=bootstrap)
        }
        else {
          dta <- eval(object$data, sys.parent())
          dta <- dta[complete.cases(model.frame(object, dta)),]
          if (is.null(bootfn)) {
            bootfn <- function(data, i, obj) {
              d <- data[i,]
              obj$call$data <- d
              fit <- eval(obj$call, sys.parent())
              return(param(fit, bootstrap = TRUE))
            }
          }
          res0 <- boot(dta, bootfn, R=num, obj = object$lower.estimate, ...)
          res1 <- boot(dta, bootfn, R=num, obj = object$upper.estimate, ...)
          colnames(res0$t) <- names(res0$t0)
          colnames(res1$t) <- names(res1$t0)
          par0 <- res0$t
          par1 <- res1$t
        }
        sim00 <- qi.glm(object$lower.estimate, par0, x = x)
        P00 <- as.matrix(sim00$qi$ev)
        sim10 <- qi.glm(object$upper.estimate, par1, x = x)
        P10 <- as.matrix(sim10$qi$ev)
        test <- P00[,1] < P10[,1]
        par0 <- as.matrix(par0[test,])
        par1 <- as.matrix(par1[test,])
        list(par0 = par0, par1 = par1)
      }
      tmp <- pping(object, bootstrap=bootstrap, bootfn=bootfn, x=x, x1=x1, num=num, ...)
      par0 <- tmp$par0
      par1 <- tmp$par1
      while (nrow(par0) < num) {
        tmp <- pping(object, bootstrap=bootstrap, bootfn=bootfn, x=x, x1=x1, num=num,...)
        par0 <- rbind(par0, tmp$par0)
        par1 <- rbind(par1, tmp$par1)
      }
      if (nrow(par0) > num) {
        par0 <- par0[1:num,]
        par1 <- par1[1:num,]
      }
      par0 <- as.matrix(par0)
      par1 <- as.matrix(par1)
      rownames(par0) <- 1:nrow(par0)
      rownames(par1) <- 1:nrow(par1)
    }
    else {
      if (! length(prev) == 2)
        stop("Error: length(tau) must equal the number of sets previous \nparameters ('prev').")
      else {
        par0 <- prev$par0
        par1 <- prev$par1
      }
    }
    res$par <- list(par0 = par0, par1 = par1)
    low <- qi.glm(object$lower.estimate, par0, x, x1)
    up <- qi.glm(object$upper.estimate, par1, x, x1)
    PP <- PR <- array(NA, dim = c(num, 2, nrow(x)),
                      dimnames = list(NULL, c("Lower Bound", "Upper Bound"),
                        rownames(x)))
    PP[,1,] <- P00 <- low$qi$ev
    PP[,2,] <- P10 <- up$qi$ev
    PR[,1,] <- low$qi$pr
    PR[,2,] <- up$qi$pr
    qi <- list(ev = PP, pr = PR)
    qi.name <- low$qi.name
    if (!is.null(x1)) {
      FD <- RR <- array(NA, dim = c(num, 2, nrow(x)),
                        dimnames = list(NULL, d2 = c("Lower Bound", "Upper Bound"), 
                          rownames(x)))
      sim01 <- qi.glm(object$lower.estimate, par0, x = x1, x1 = NULL)
      sim11 <- qi.glm(object$upper.estimate, par1, x = x1, x1 = NULL)
      tau0 <- object$lower.estimate$call$tau
      tau1 <- object$upper.estimate$call$tau
      P01 <- as.matrix(sim01$qi$ev)
      P11 <- as.matrix(sim11$qi$ev)
      OR <- (P10/(1-P10)) / (P00/(1-P00))
      RR[,1,] <- pmin(as.matrix(P01/P00), as.matrix(P11/P10))
      RR[,2,] <- pmax(as.matrix(P01/P00), as.matrix(P11/P10))
      RD0 <- as.matrix(P01-P00)
      RD1 <- as.matrix(P11-P10)
      RD <- as.matrix((sqrt(OR)-1) / (sqrt(OR)+1))
      ## checking monotonicity
      y.bar <- mean(object$lower.estimate$y)
      beta0.e <- object$lower.estimate$coefficients
      beta1.e <- object$upper.estimate$coefficients
      ## evaluating RD at tau0 and tau1
      RD0.p <- 1/(1+exp(-t(beta0.e) %*% t(x1))) - 1/(1+exp(-t(beta0.e) %*% t(x)))
      RD1.p <- 1/(1+exp(-t(beta1.e) %*% t(x1))) - 1/(1+exp(-t(beta1.e) %*% t(x)))
      ## evaluating RD at tau0+e and tau1+e
      e <- 0.001
      beta0.e["(Intercept)"] <- beta0.e["(Intercept)"]+log(1-tau0)-log(tau0) -
        log(1-tau0-0.001)+log(tau0+0.001)
      beta1.e["(Intercept)"] <- beta1.e["(Intercept)"]+log(1-tau1)-log(tau1) -
        log(1-tau1-e)+log(tau1+e)
      RD0.e <- 1/(1+exp(-t(beta0.e) %*% t(x1))) - 1/(1+exp(-t(beta0.e) %*% t(x)))
      RD1.e <- 1/(1+exp(-t(beta1.e) %*% t(x1))) - 1/(1+exp(-t(beta1.e) %*% t(x)))
      ## checking the sign and computing the bounds
      check <- sum((RD1.e-RD1.p) * (RD0.e-RD0.p))
      if (check > 0) {
        FD[,1,] <- pmin(RD0, RD1)
        FD[,2,] <- pmax(RD0, RD1)
      }
      else {
        FD[,1,] <- pmin(RD0, RD1, RD)
        FD[,2,] <- pmax(RD0, RD1, RD)
      }
      qi$fd <- FD
      qi$rr <- RR
      qi.name$fd <- "First Differences: P(Y=1|X1) - P(Y=1|X)"
      qi.name$rr <- "Risk Ratios: P(Y=1|X1) / P(Y=1|X)"
    }
    res$qi <- qi
    res$qi.name <- qi.name
    res$tau <- tau
  }
  else { # with precise population info, or no population info
    if (is.null(prev)) {
      if (!bootstrap) 
        simpar <- param.default(object, num=num, bootstrap = bootstrap)
      else {
        tt <- terms(object)
        dta <- eval(object$data, sys.parent())
        dta <- dta[complete.cases(model.frame(tt, dta)),]
        if(is.null(bootfn)) {
          bootfn <- function(data, i, object) {
            d <- data[i,]
            object$call$data <- d
            fit <- eval(object$call, sys.parent())
            return(param(fit, bootstrap = TRUE))
          }
        }
        res <- boot(dta, bootfn, R = num, object = object, ...)
        colnames(res$t) <- names(res$t0)
        simpar <- res$t
      }        
    }
    else
      simpar <- prev
    simqi <- qi.glm(object, simpar, x = x, x1 = x1)
    res$par <- simpar
    res$qi <- simqi$qi
    res$qi.name <- simqi$qi.name
  }
  res$call$num <- num
  class(res) <- "zelig"
  res
}
























































