zelig <- function(formula, model, data, by, equal, ones, zeros, tau,
                  bias.correct = TRUE, ...) {
  mf <- match.call()
  mf$model <- mf$by <- mf$equal <- mf$ones <- mf$zeros <- mf$tau <-
    mf$bias.correct <- mf$... <- NULL
  if (missing(by))
    by <- NULL
  if (!is.null(by)) {
    if (!is.data.frame(data))
      stop("Error: subsetting using 'by' is currently not supported for MI datasets.")  
    temp <- list()
    if (as.character(by) %in% c(formula[[2]], formula[[3]]))
      stop("Error: the variable selected for subsetting cannot be called in the formula.")
    if (as.character(by) %in% names(data)) {
      mf$by <- as.name(by)
      by <- eval(mf$by, data)
      mf$by <- NULL
      lev <- sort(unique(by))
      for (i in 1:length(lev))
        temp[[i]] <- data[by == lev[i],]
      names(temp) <- lev
      data <- temp
    }
  }
  object <- list()
  M <- 1
  if (!is.data.frame(data)) {
    M <- length(data)
    dta <- data
  }
  else
    d <- data
  if(model == "ls") 
    mf[[1]] <- as.name("lm")
  else if(model=="normal") { 
    mf[[1]] <- as.name("glm")
    mf$family <- as.name("gaussian")
  }
  else if(model == "logit") { 
    mf[[1]] <- as.name("glm")
    mf$family <- as.name("binomial")
  }
  else if(model == "probit") { 
    mf[[1]] <- as.name("glm")
    mf$family <- as.name("binomial.probit")
    binomial.probit <- function() binomial(link="probit")
  }
  else if(model == "gamma") { 
    mf[[1]] <- as.name("glm")
    mf$family <- as.name("Gamma")
  }
  else if(model == "poisson") {
    mf[[1]] <- as.name("glm")
    mf$family <- as.name("poisson")
  }
  else if(model == "relogit") { 
    mf[[1]] <- as.name("relogit")
    mf$tau <- tau
    mf$bias.correct <- bias.correct
  }
  else if(model == "mloglm") { 
    require(nnet)
    mf[[1]] <- as.name("multinom")
    mf$Hess <- TRUE
  }
  else if(model == "negbin") 
    mf[[1]] <- as.name("glm.nb")
  else if(model == "ologit"){ 
    mf[[1]] <- as.name("polr")
    mf$Hess <- TRUE
  }
  else if(model == "exp"){ 
    require(survival)
    mf[[1]] <- as.name("survreg")
    mf$dist <- as.character("exponential")
  }
  else if(model == "lognorm"){ 
    require(survival)
    mf[[1]] <- as.name("survreg")
    mf$dist <- as.character("lognormal")
  }
  else if(model == "weibull"){ 
    require(survival)
    mf[[1]] <- as.name("survreg")
    mf$dist <- as.character("weibull")
  }
  else if(model == "oprobit"){
    require(VGAM)
    if(missing(equal)) {
      ordinal.probit <- function() cumulative(link=probit, parallel=T)
      equal <- NULL
    }
    else
      ordinal.probit <- function() cumulative(link=probit)
    if(missing(ones))
      ones <- NULL
    if(missing(zeros))
      zeros <- NULL
    mf[[1]] <- as.name("vglm")
    mf$family <- as.name("ordinal.probit")
    if (M == 1)
      ndim <- length(unique(na.omit((eval(formula[[2]], data))))) - 1
    if (M > 1) {
      ntmp <- array()
      for (i in 1:M) 
        ntmp[i] <- length(unique(na.omit((eval(formula[[2]], data[[i]]))))) - 1
      ndim <- max(ntmp)
    }
    tmp <- cmvglm(formula, model, equal, zeros, ones, ndim) 
    constraints <- tmp$constraints
    mf$formula <- tmp$formula
    mf$constraints <- as.name("constraints")
  }
  else if(model == "blogit") { 
    require(VGAM)
    if(missing(equal))
      equal <- NULL
    if(missing(ones))
      ones <- 3
    if(missing(zeros))
      zeros <- NULL
    mf[[1]] <- as.name("vglm")
    mf$family <- as.name("blogit")
    tmp <- cmvglm(formula, model, equal, zeros, ones, 3) 
    constraints <- tmp$constraints
    mf$formula <- tmp$formula
    mf$constraints <- as.name("constraints")
    blogit <- function() binom2.or(zero=NULL)
  }
  else if(model == "bprobit") {
    require(VGAM)
    if(missing(equal))
      equal <- NULL
    if(missing(ones))
      ones <- 3
    if(missing(zeros))
      zeros <- NULL
    mf[[1]] <- as.name("vglm")
    mf$family <- as.name("bprobit")
    tmp <- cmvglm(formula, model, equal, zeros, ones, 3) 
    constraints <- tmp$constraints
    mf$formula <- tmp$formula
    mf$constraints <- as.name("constraints")
    bprobit <- function() binom2.rho(zero=NULL)
  }
  else if(model == "mlogit") { 
    require(VGAM)
    if(missing(equal))
      equal <- NULL
    if(missing(ones))
      ones <- NULL
    if(missing(zeros))
      zeros <- NULL
    mf[[1]] <- as.name("vglm")
    mf$family <- as.name("multinomial")
    if (M == 1)
      ndim <- length(unique(na.omit((eval(formula[[2]], data))))) - 1
    if (M > 1) {
      ntmp <- array()
      for (i in 1:M) 
        ntmp[i] <- length(unique(na.omit((eval(formula[[2]], data[[i]]))))) - 1
      ndim <- max(ntmp)
    }
    tmp <- cmvglm(formula, model, equal, zeros, ones, ndim) 
    constraints <- tmp$constraints
    mf$formula <- tmp$formula
    mf$constraints <- as.name("constraints")
  }
  else if(model=="sur") { # currently not implemented in VGAM, buggy. 
    require(VGAM)
    if(missing(equal))
      equal <- NULL
    if(missing(ones))
      ones <- NULL
    if(missing(zeros))
      zeros <- NULL
    mf[[1]] <- as.name("vglm")
    mf$family <- as.name("gaussianff")
    gaussianff.control <- control.gaussianff # bug fix in VGAM
  }
  else
    stop(paste("Error:", model, "not supported. Type help.zelig(\"models\") to list supported models."))
  for (i in 1:M){
    if (M > 1) 
      d <- eval(dta[[i]], sys.parent())
    if (is.data.frame(d)){
      d <- d[complete.cases(model.frame(as.formula(formula), d)),]
      mf$data <- d
      res <- eval(as.call(mf))
      res$call <- match.call()
      res$data <- res$call$data
      res$zelig <- model
      if (model == "relogit") 
        res$call$bias.correct <- bias.correct
      if (M > 1) 
        object[[i]] <- res
      else
        object <- res
    }
    else
      stop(paste("Error:", class(data), "is not a supported data format."))
  }
  if (model == "relogit" && length(tau) == 2) {
      object$lower.estimate$call <- object$upper.estimate$call <- object$call
      object$lower.estimate$call$tau <- round(min(tau), digits = getOption("digits"))
      object$upper.estimate$call$tau <- round(max(tau), digits = getOption("digits"))
    }
  if (M > 1)
    if (is.null(by)) 
      class(object) <- "MI"
    else {
      names(object) <- lev
      class(object) <- "multiple"
    }
  object
}
