\name{names}

\alias{names.zelig}
\alias{names.summary.zelig}

\title{Viewing the Elements in Zelig Objects}

\description{
  The generic function \code{names} returns the named elements within an
  object.  For objects created using \code{\link{zelig}} and
  \code{\link{sim}}, \code{names} returns the sub-elements of
  object-level elements.  Use the \code{$} operator to extract
  elements from list objects.  The full Zelig manual (containing 
  full model specifications and detailed examples) is available 
  online at \url{http://gking.harvard.edu/zelig}.  
  }
  
\usage{
names(x)
names.zelig(x)
names.summary.zelig(x)
names(x) <- value
}

\arguments{
  \item{x}{an R object.  For objects of class \code{zelig}, \code{names}
  defaults to \code{names.zelig} or \code{names.summary.zelig} as
  appropriate.}
  \item{value}{a character vector of up to the same length as \code{x},
    or \code{NULL} to clear the names from the object.}
}

\value{
  For the generic function \code{names}, \code{NULL} or a character
  vector of the same length as \code{x}.

  For the Zelig versions of \code{names}, the elements as well as the
  sub-structure of the elements \code{qi} and \code{qi.stats}.  
}

\seealso{\code{\link{zelig}}, \code{\link{setx}}, \code{\link{sim}},
  and \code{\link{summary.zelig}}.  In addition, the
  full Zelig manual may be accessed online at
  \url{http://gking.harvard.edu/zelig}.
  }

\author{
  Kosuke Imai <\email{kimai@princeton.edu}>; Gary King
  <\email{king@harvard.edu}>; Olivia Lau <\email{olau@fas.harvard.edu}>
}

\references{Gary King, Michael Tomz, and Jason Wittenberg (2000),
``Making the Most of Statistical Analyses: Improving Interpretation and
  Presentation,'' \emph{American Journal of Political Science}, vol. 44,
  pp.347--355. \cr
}

\examples{
data(turnout)

##  Returning the variables in the data frame:  

names(turnout)

##  Generating sample Zelig objects:

estimate <- zelig(vote ~ age + income, model = "logit", data = turnout)
Xval <- setx(estimate)
results <- sim(estimate, x = Xval)

##  Extracting names from objects of class zelig:

names(estimate)
names(results)
names(summary(results))
}

\keyword{file}
